import sys

def get_block_name(z, y, x, block_size=500):
    """Convert coordinates to block name based on the format: cell_yxz_{by+1:03}_{bx+1:03}_{bz+1:03}.tif"""
    # Calculate block indices (adding 1 since the original format uses 1-based indexing)
    bz = (z // block_size) + 1
    by = (y // block_size) + 1
    bx = (x // block_size) + 1
    
    # Format filename according to the original pattern
    return f"cell_yxz_{by:03}_{bx:03}_{bz:03}.tif"

def main():
    print("Enter coordinates as 'z y x' (or Ctrl+C to exit)")
    print("Example: 1500 2000 3000")
    
    while True:
        try:
            # Get user input
            user_input = input("\nEnter coordinates: ").strip()
            
            # Parse the coordinates
            try:
                z, y, x = map(int, user_input.split())
                
                # Get and display the block name
                block_name = get_block_name(z, y, x)
                print(f"\nCoordinate ({z}, {y}, {x}) is in block: {block_name}")
                
            except ValueError:
                print("Invalid input. Please enter three numbers separated by spaces.")
                
            # Wait for enter to continue
            input("\nPress Enter to continue...")
            
        except KeyboardInterrupt:
            print("\nExiting...")
            sys.exit(0)

if __name__ == "__main__":
    main()